@@ -1,5 +1,5 @@
-from .client import Aladhan
+from .client import Client
 from .location_types import City, Address, Coordinates
 from .exceptions import *
 
-__version__ = (5, 0, 0)
\ No newline at end of file
+__version__ = (6, 0, 0)
\ No newline at end of file
