@@ -2,6 +2,14 @@ from time import sleep
 from datetime import datetime
 import threading
 
+TRANSLATE = {
+    "Fajr": {"ar": "فجر", "tashkeel_ar": "فَجْرٌ"},
+    "Dhuhr": {"ar": "ظهر", "tashkeel_ar": "ظُهْرٌ"},
+    "Asr": {"ar": "عصر", "tashkeel_ar": "عَصْرٌ"},
+    "Maghrib": {"ar": "مغرب", "tashkeel_ar": "مَغْرِبٌ"},
+    "Isha": {"ar": "عشاء", "tashkeel_ar": "عَشَاءٌ"}
+}
+
 
 class Adhan:
 
@@ -61,7 +69,7 @@ class Adhan:
         else:
             return self.datetime_obj.strftime(format_)
 
-    def wait(self, callback=None, threaded_wait=False, **kwargs):
+    def wait(self, callback=None, threaded_wait=False, *args, **kwargs):
         """
         Wait until the salah time has passed.
         
@@ -74,7 +82,7 @@ class Adhan:
                     break
                 sleep(1)
             if callback:
-                callback(**kwargs)
+                callback(*args, **kwargs)
 
         if threaded_wait:
             threading.Thread(target=wait_function).start()
@@ -101,23 +109,24 @@ class Adhan:
         elif self.name == 'Maghrib': return 3
         elif self.name == 'Isha': return 4
 
-    def get_name(self, lang='en') -> str:
+    def get_en_name(self) -> str:
+        """Returns the English name of the salah."""
+        return self.name
+    
+    def get_ar_name(self, tashkeel: bool=False, include_al: bool=True) -> str:
         """
-        Returns the name of the salah in English.
-
-        - `lang: str='en'` set to 'ar' to get the name in Arabic.
+        Returns the Arabic name of the salah.
+        
+        - `tashkeel: bool=False` to include tashkeel or not (e.g. مَغْرِبٌ).
+        - `include_al: bool=True` to include the definite article (ال) or not (e.g. العشاء instead of عشاء).
         """
-        translate = {
-            'Fajr': 'الفجر',
-            'Dhuhr': 'الظهر',
-            'Asr': 'العصر',
-            'Maghrib': 'المغرب',
-            'Isha': 'العشاء'
-        }
-        if lang == 'ar':
-            return translate[self.name]
-        else:
-            return self.name
+        name = TRANSLATE[self.name]['ar']
+        if tashkeel:
+            name = TRANSLATE[self.name]['tashkeel_ar']
+        if include_al:
+            name = 'ال' + name
+        
+        return name
 
     def sunnan_al_rawatib(self) -> dict:
         """Returns a dictionary with the number of sunnah prayers `before` and `after` the salah."""
