@@ -1,5 +1,4 @@
 from datetime import datetime
-from time import sleep
 from .location_types import Coordinates, Address, City
 from .adhan import Adhan
 from .exceptions import *
@@ -11,7 +10,7 @@ API = 'https://api.aladhan.com/v1/'
 SKIP = ['Sunrise', 'Sunset', 'Midnight', 'Lastthird', 'Firstthird', 'Imsak']
 
 
-class Aladhan:
+class Client:
 
 
     def __init__(self, default_location: Union[Coordinates, Address, City] = None):
